#!/bin/bash
CALAMARIS_COMMAND=/usr/local/calamaris/calamaris
:<< _EOF

This script generates a real time analysis of traffic by parsing access.log with calamaris script
This Script can be used as an External Parser with SafeSquid
_EOF

SAMPLING=0
LOG_FILE=/opt/safesquid/safesquid/logs/access/*access*

#STEPS=60
STEPS=1

# REPORT_TYPE
# 0 = Real-time, last 4 hours
# 1 = daily, last 1 day
# 2 = weekly, last 7 days
# 3 = monthly, last month

REPORT_TYPE=

DEBUGGING=0 # set DEBUGGING to 1 to disable

CONFIGURE_PERIOD ()
{
	
#	REPORT_SINCE=`date --date="100 hour ago" +%Y%m%d%H%M%S`

	case ${REPORT_TYPE} in
		0)
			;;
		1)
			;;
		*)
	
	esac



	# START_YEAR=`date +%Y`
	# START_MONTH=`date +%m`
	# START_DATE=`date +%d`
	# START_HOUR=`date +%H`
	# START_MINUTE=`date +%M`
	# START_SECOND=`date +%S`

	START_YEAR=2009
	START_MONTH=01
	START_DATE=23
	START_HOUR=23
	START_MINUTE=00
	START_SECOND=00
	

	END_YEAR=2010
	END_MONTH=02
	END_DATE=25
	END_HOUR=19
	END_MINUTE=40
	END_SECOND=00

#	REPORT_UPTO=`date +%Y%m%d%H%M%S`
	REPORT_SINCE=${START_YEAR}${START_MONTH}${START_DATE}${START_HOUR}${START_MINUTE}${START_SECOND}
	
	
	REPORT_UPTO=${END_YEAR}${END_MONTH}${END_DATE}${END_HOUR}${END_MINUTE}${END_SECOND}

return;
}


# CACHE_FILE=/var/logreports/calamaris/calamaris-cache
OUTPUT_FILE=${HOSTNAME}-`date +%Y%m%d%H%M%S`.html
OUTPUT_PATH=/var/logreports/calamaris/
OUTPUT_FILE_PREFIX=current-production-


# define the output parameters
FORMAT=html
:<< _COM 
        mail        = mail format, disables graph output.
        html        = HTML format
        html-frame  = HTML frames, disables mail output.
        html-embed  = HTML format without HTML-headers.
        graph       = enable graphics, needs GD::Graph, only useful with html
                      or html-embed, see --output-path. Disables mail output.
        unformatted = plain unformatted output
_COM


[ "x${1}" != "x" ] && FORMAT=${1}
[ -d ${OUTPUT_PATH} ] || mkdir -p ${OUTPUT_PATH} || OUTPUT_PATH=

SET_PARAMS ()
	{



	if [ ! -f ${CALAMARIS_COMMAND} ]
	then
		echo "Calamaris not found at ${CALAMARIS_COMMAND} "
	exit
	fi
			
	# set all the parameters as arguments to CALAMARIS_COMMAND
	[ "x${OUTPUT_FILE_PREFIX}" != "x" ] && CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --output-file-prefix ${OUTPUT_FILE_PREFIX}`
	[ "x${OUTPUT_FILE_PREFIX}" != "x" ] && CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --output-file ${OUTPUT_FILE}`
	[ "x${OUTPUT_PATH}" != "x" ] && CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --output-path ${OUTPUT_PATH}`
	[ "x${FORMAT}" != "x" ] && CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND} -F ${FORMAT}`
	[ "x${REPORT_SINCE}" != "x" ]  && [ "x${REPORT_UPTO}" != "x" ] && CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --time-interval ${REPORT_SINCE}-${REPORT_UPTO}`
	[ "x${CACHE_FILE}" != "x" ] && [ -f ${CACHE_FILE} ] &&	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --cache-input-file ${CACHE_FILE}`
	[ "x${CACHE_FILE}" != "x" ] && CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --cache-output-file ${CACHE_FILE}`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --domain-report -1`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --domain-report-n-level -1`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --errorcode-distribution-report`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --peak-report new`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --performance-report ${STEPS}`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  -T ${STEPS}`	
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --requester-report -1`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --requester-report-use-user-info`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --requester-report-with-targets -1`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --response-time-report`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --size-distribution-report 10`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --status-report`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --type-report 50`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --type-report-ignore-case`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --input-format squid`
	CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  --hostname current-squid-server`
	[ "x${DEBUGGING}" == "x0" ] && CALAMARIS_COMMAND=`echo ${CALAMARIS_COMMAND}  -v --benchmark 100`

	return;
	}



# Tail the required number of lines and pipe it into calamaris

# tail -n ${SAMPLING} ${LOG_FILE} | ${CALAMARIS_COMMAND} -a -P 1 

# tail -n ${SAMPLING} ${LOG_FILE} | ${CALAMARIS_COMMAND} -a -P 1 -S "0,1,2.3,5,6,7,8,9,10,11,12,13,14,15,16,18,20"
if [ ${SAMPLING} == 0 ]
then
	CONFIGURE_PERIOD
	

	SET_PARAMS

	echo "executing:"
	echo ${CALAMARIS_COMMAND}
	
	cat ${LOG_FILE} | ${CALAMARIS_COMMAND}
#	cat ${LOG_FILE}
else
	SET_PARAMS

	tail -n ${SAMPLING} ${LOG_FILE} | ${CALAMARIS_COMMAND}
fi

exit 0

